//
//  StandardShader.glsl
//
//  Created by michael tesch.
//  Copyright (c) 2016 michael tesch. All rights reserved.
//
//  Combined vertex/fragment shader
//

#ifdef COMPILEVS

// Silence GLSL 150 deprecation warnings
#ifdef GL3
#define attribute in
#define varying out
#endif

attribute vec3 position;
attribute vec2 arrAtt;

varying mediump vec2 pos;
varying mediump vec2 vAttribs;

uniform mat4 MVPMatrix;

void main()
{
    vAttribs = arrAtt;
    pos = position.xy;

    gl_Position = MVPMatrix * vec4(position, 1);
}

#else // COMPILEFS

#ifdef GL3
#define varying in
out vec4 fragData[1];
#define gl_FragColor fragData[0]
#endif

#define Diffuse (1.)
#define Ambient (0.5)
#define SHININESS (18.)
#define Specular (0.7)

uniform highp mat3 normalMatrix;
uniform lowp vec4 color;

varying mediump vec2 pos;
varying mediump vec2 vAttribs;

void main()
{
    mediump vec2 posn = normalize(pos);
    mediump vec3 normalStatic = normalize(vec3(posn.x * vAttribs.x * vAttribs.y,
                                               posn.y * vAttribs.x * vAttribs.y,
                                               2. * vAttribs.y - 1.));
    mediump vec3 Normal = normalize(vec3(normalMatrix * normalStatic));

    lowp vec3 SpecularMaterial = vec3(Specular);
    highp vec3 Light = normalize(vec3(1,0,1));
    highp vec3 Eye = vec3(0,0,1);
    highp vec3 H = normalize(Light + Eye);

    highp float df = max(0.0, dot(Normal, Light));
    highp float sf = max(0.0, dot(Normal, H));

    sf = pow(sf, SHININESS);
    lowp vec3 col = color.rgb * Ambient + color.rgb * Diffuse * df + SpecularMaterial * sf;

    gl_FragColor = vec4(col, color.w);
}

#endif // COMPILEVS/FS
