//
// A basic fragment shader
//
#ifdef COMPILEFS

#ifdef GL3
#define varying in
out vec4 fragData[1];
#define gl_FragColor fragData[0]
#define texture2D texture
#endif

//Default precision qualifier
//precision highp float;

//This represents the current texture on the mesh

#define SHININESS       (20.)
#define DIFFUSE         (1.)
#define AMBIENT         (0.2)

//The interpolated vertex color for this fragment
varying highp vec3 eyeNormal;
varying highp vec2 value;

uniform mediump float alpha;
uniform sampler2D phaseColorTex;

void main()
{
    lowp vec3 SpecularMaterial = vec3(0.8);
    lowp vec3 DiffuseMaterial;
    lowp vec3 AmbientMaterial;
    highp vec3 Normal = normalize(eyeNormal);
    //highp vec3 Light = normalize(vec3(0.2, -1., .5));
    //highp vec3 E = vec3(0, 0, .05);
    highp vec3 Light = normalize(vec3(1,0,1));
    highp vec3 E = vec3(0,0,1); // eye?
    highp vec3 H = normalize(Light + E);

    highp float df = max(0.0, dot(Normal, Light));
    highp float sf = max(0.0, dot(Normal, H));
    
    lowp float unitPhase = atan(value.y, value.x) / (2.0 * M_PI);
    lowp vec4 color = texture2D(phaseColorTex, vec2(unitPhase + 0.5, 0));
    DiffuseMaterial = color.xyz * DIFFUSE;
    AmbientMaterial = color.xyz * AMBIENT;

    sf = pow(sf, SHININESS);
    lowp vec3 col = AmbientMaterial + DiffuseMaterial * df + SpecularMaterial * sf;
    col = clamp(col, 0.0, 1.0);

    // Set the output color to the texture color
    gl_FragColor = vec4(col, alpha);
}

#endif // COMPILEFS
