//
//  StandardShader.glsl
//
//  Copyright (c) 2016 michael tesch. All rights reserved.
//
//  Combined vertex/fragment shader
//

#ifdef COMPILEVS

// Silence GLSL 150 deprecation warnings
#ifdef GL3
#define attribute in
#define varying out
#endif

attribute vec3 position;
attribute vec3 normal;
attribute vec4 color;
attribute vec2 texCoord;

uniform mat4 MVPMatrix;
#ifdef HASUNIFORM_normalMatrix
#define Diffuse (1.)
#define Ambient (0.2)
uniform mat3 normalMatrix;
#endif
//uniform sampler2D tex;

#ifdef HASUNIFORM_normalMatrix
varying highp vec3 eyeNormal;
#endif
varying lowp vec3 DiffuseMaterial;
varying lowp vec3 AmbientMaterial;
varying lowp vec2 texCoordo;

void main()
{
#ifdef HASUNIFORM_normalMatrix
  eyeNormal = normalize(normalMatrix * normal);
  DiffuseMaterial = vec3(color) * Diffuse;
  AmbientMaterial = vec3(color) * Ambient;
#else
  AmbientMaterial = vec3(color);
#endif
  texCoordo = texCoord;
  gl_Position = MVPMatrix * vec4(position, 1);
}

#else // COMPILEFS

#ifdef GL3
#define varying in
out vec4 fragData[1];
#define gl_FragColor fragData[0]
#define texture2D texture
#endif
#define SHININESS (20.)

#ifdef HASUNIFORM_tex
uniform sampler2D tex;
#endif

#ifdef HASUNIFORM_normalMatrix
varying highp vec3 eyeNormal;
#endif
varying lowp vec3 DiffuseMaterial;
varying lowp vec3 AmbientMaterial;
varying lowp vec2 texCoordo;

void main()
{
#ifdef HASUNIFORM_normalMatrix
  lowp vec3 SpecularMaterial = vec3(0.8);
  highp vec3 Normal = normalize(eyeNormal);
  highp vec3 Light = normalize(vec3(1,0,1));
  highp vec3 Camera = vec3(0,0,1);
  highp vec3 H = normalize(Light + Camera);

  highp float df = max(0.0, dot(Normal, Light));
  highp float sf = max(0.0, dot(Normal, H));
  sf = pow(sf, SHININESS);
  lowp vec3 col = AmbientMaterial + DiffuseMaterial * df + SpecularMaterial * sf;
#else
  lowp vec3 col = AmbientMaterial;
#endif

#if 1 && defined(HASUNIFORM_tex)
  gl_FragColor = vec4(col, 1) * texture2D(tex, texCoordo);
#else
  gl_FragColor = vec4(col, 1);
#endif
}

#endif // COMPILEVS/FS
